<?php

namespace Laraecart\Attribute\Providers;

use Illuminate\Support\ServiceProvider;

class AttributeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'attribute');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'attribute');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('laraecart.attribute', function ($app) {
            return $this->app->make('Laraecart\Attribute\Attribute');
        });

        // Bind Attribute to repository
        $this->app->bind(
            'Laraecart\Attribute\Interfaces\AttributeRepositoryInterface',
            \Laraecart\Attribute\Repositories\Eloquent\AttributeRepository::class
        );
        // Bind AttributeGroup to repository
        $this->app->bind(
            'Laraecart\Attribute\Interfaces\AttributeGroupRepositoryInterface',
            \Laraecart\Attribute\Repositories\Eloquent\AttributeGroupRepository::class
        );

        $this->app->register(\Laraecart\Attribute\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Laraecart\Attribute\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['laraecart.attribute'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('laraecart/attribute.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/attribute')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/attribute')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
