<?php

namespace Laraecart\Attribute\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Laraecart\Attribute\Models\Attribute;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Laraecart\Attribute\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/attribute/attribute/*')) {
            Route::bind('attribute', function ($attribute) {
                $attributerepo = $this->app->make('Laraecart\Attribute\Interfaces\AttributeRepositoryInterface');
                return $attributerepo->findorNew($attribute);
            });
        }

        if (Request::is('*/attribute/attribute_group/*')) {
            Route::bind('attribute_group', function ($attribute_group) {
                $attribute_grouprepo = $this->app->make('Laraecart\Attribute\Interfaces\AttributeGroupRepositoryInterface');
                return $attribute_grouprepo->findorNew($attribute_group);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
